@@ -4,10 +4,11 @@
 # See top-level LICENSE file for more information
 
 import importlib
-from typing import Any, Dict, List
+from typing import TYPE_CHECKING, Any, Dict, List
 import warnings
 
-from .interface import StorageInterface
+if TYPE_CHECKING:
+    from .interface import StorageInterface
 
 
 STORAGE_IMPLEMENTATIONS = {
@@ -22,15 +23,19 @@ STORAGE_IMPLEMENTATIONS = {
 }
 
 
-def get_storage(cls: str, **kwargs) -> StorageInterface:
+def get_storage(cls: str, **kwargs) -> "StorageInterface":
     """Get a storage object of class `storage_class` with arguments
     `storage_args`.
 
     Args:
-        storage (dict): dictionary with keys:
-        - cls (str): storage's class, either local, remote, memory, filter,
-            buffer
-        - args (dict): dictionary with keys
+        cls (str): storage's class, can be:
+          - ``local`` to use a postgresql database
+          - ``cassandra`` to use a cassandra database
+          - ``remote`` to connect to a swh-storage server
+          - ``memory`` for an in-memory storage, useful for fast tests
+          - ``filter``, ``buffer``, ... to use specific storage "proxies", see their
+            respective documentations
+        args (dict): dictionary with keys
 
     Returns:
         an instance of swh.storage.Storage or compatible class
@@ -69,7 +74,7 @@ def get_storage(cls: str, **kwargs) -> StorageInterface:
 
 def get_storage_pipeline(
     steps: List[Dict[str, Any]], check_config=None
-) -> StorageInterface:
+) -> "StorageInterface":
     """Recursively get a storage object that may use other storage objects
     as backends.
 
