@@ -4,20 +4,26 @@
 # See top-level LICENSE file for more information
 
 from functools import partial
-from typing import Collection, Dict, Iterable, List, Mapping, Optional, Tuple
+from typing import Dict, Iterable, Mapping, Sequence, Tuple
+
+from typing_extensions import Literal
 
 from swh.core.utils import grouper
 from swh.model.model import BaseModel, Content, SkippedContent
 from swh.storage import get_storage
 from swh.storage.interface import StorageInterface
 
-OBJECT_TYPES: List[str] = [
+LObjectType = Literal[
+    "content", "skipped_content", "directory", "revision", "release", "snapshot"
+]
+OBJECT_TYPES: Tuple[LObjectType, ...] = (
     "content",
     "skipped_content",
     "directory",
     "revision",
     "release",
-]
+    "snapshot",
+)
 
 DEFAULT_BUFFER_THRESHOLDS: Dict[str, int] = {
     "content": 10000,
@@ -26,6 +32,7 @@ DEFAULT_BUFFER_THRESHOLDS: Dict[str, int] = {
     "directory": 25000,
     "revision": 100000,
     "release": 100000,
+    "snapshot": 25000,
 }
 
 
@@ -52,18 +59,16 @@ class BufferingProxyStorage:
               directory: 5000
               revision: 1000
               release: 10000
+              snapshot: 5000
 
     """
 
-    def __init__(
-        self, storage: Mapping, min_batch_size: Mapping = DEFAULT_BUFFER_THRESHOLDS,
-    ):
+    def __init__(self, storage: Mapping, min_batch_size: Mapping = {}):
         self.storage: StorageInterface = get_storage(**storage)
 
-        if min_batch_size is not DEFAULT_BUFFER_THRESHOLDS:
-            self._buffer_thresholds = {**DEFAULT_BUFFER_THRESHOLDS, **min_batch_size}
+        self._buffer_thresholds = {**DEFAULT_BUFFER_THRESHOLDS, **min_batch_size}
 
-        self._objects: Dict[str, Dict[Tuple[str, ...], BaseModel]] = {
+        self._objects: Dict[LObjectType, Dict[Tuple[str, ...], BaseModel]] = {
             k: {} for k in OBJECT_TYPES
         }
         self._contents_size: int = 0
@@ -77,7 +82,7 @@ class BufferingProxyStorage:
             raise AttributeError(key)
         return getattr(self.storage, key)
 
-    def content_add(self, contents: Collection[Content]) -> Dict:
+    def content_add(self, contents: Sequence[Content]) -> Dict:
         """Push contents to write to the storage in the buffer.
 
         Following policies apply:
@@ -98,7 +103,7 @@ class BufferingProxyStorage:
 
         return stats
 
-    def skipped_content_add(self, contents: Collection[SkippedContent]) -> Dict:
+    def skipped_content_add(self, contents: Sequence[SkippedContent]) -> Dict:
         return self.object_add(
             contents,
             object_type="skipped_content",
@@ -106,7 +111,11 @@ class BufferingProxyStorage:
         )
 
     def object_add(
-        self, objects: Collection[BaseModel], *, object_type: str, keys: Iterable[str],
+        self,
+        objects: Sequence[BaseModel],
+        *,
+        object_type: LObjectType,
+        keys: Iterable[str],
     ) -> Dict[str, int]:
         """Push objects to write to the storage in the buffer. Flushes the
         buffer to the storage if the threshold is hit.
@@ -121,10 +130,14 @@ class BufferingProxyStorage:
 
         return {}
 
-    def flush(self, object_types: Optional[List[str]] = None) -> Dict[str, int]:
-        summary: Dict[str, int] = self.storage.flush(object_types)
-        if object_types is None:
-            object_types = OBJECT_TYPES
+    def flush(
+        self, object_types: Sequence[LObjectType] = OBJECT_TYPES
+    ) -> Dict[str, int]:
+        summary: Dict[str, int] = {}
+
+        def update_summary(stats):
+            for k, v in stats.items():
+                summary[k] = v + summary.get(k, 0)
 
         for object_type in object_types:
             buffer_ = self._objects[object_type]
@@ -132,13 +145,17 @@ class BufferingProxyStorage:
             for batch in batches:
                 add_fn = getattr(self.storage, "%s_add" % object_type)
                 stats = add_fn(list(batch))
-                summary = {k: v + summary.get(k, 0) for k, v in stats.items()}
+                update_summary(stats)
+
+        # Flush underlying storage
+        stats = self.storage.flush(object_types)
+        update_summary(stats)
 
         self.clear_buffers(object_types)
 
         return summary
 
-    def clear_buffers(self, object_types: Optional[List[str]] = None) -> None:
+    def clear_buffers(self, object_types: Sequence[LObjectType] = OBJECT_TYPES) -> None:
         """Clear objects from current buffer.
 
         WARNING:
@@ -148,13 +165,10 @@ class BufferingProxyStorage:
             you want to continue your processing.
 
         """
-        if object_types is None:
-            object_types = OBJECT_TYPES
-
         for object_type in object_types:
             buffer_ = self._objects[object_type]
             buffer_.clear()
             if object_type == "content":
                 self._contents_size = 0
 
-        return self.storage.clear_buffers(object_types)
+        self.storage.clear_buffers(object_types)
