@@ -5,7 +5,7 @@
 
 import datetime
 from enum import Enum
-from typing import Any, Dict, Iterable, List, Optional, Tuple, TypeVar, Union
+from typing import Any, Dict, Iterable, List, Optional, Sequence, Tuple, TypeVar, Union
 
 from typing_extensions import Protocol, TypedDict, runtime_checkable
 
@@ -924,15 +924,12 @@ class StorageInterface(Protocol):
         ...
 
     @remote_api_endpoint("origin/visit_status/get_random")
-    def origin_visit_status_get_random(
-        self, type: str
-    ) -> Optional[Tuple[OriginVisit, OriginVisitStatus]]:
+    def origin_visit_status_get_random(self, type: str) -> Optional[OriginVisitStatus]:
         """Randomly select one successful origin visit with <type>
         made in the last 3 months.
 
         Returns:
-            One random tuple of (OriginVisit, OriginVisitStatus) matching the
-            selection criteria
+            One random OriginVisitStatus matching the selection criteria
 
         """
         ...
@@ -1100,7 +1097,7 @@ class StorageInterface(Protocol):
     def raw_extrinsic_metadata_get(
         self,
         type: MetadataTargetType,
-        id: Union[str, SWHID],
+        target: Union[str, SWHID],
         authority: MetadataAuthority,
         after: Optional[datetime.datetime] = None,
         page_token: Optional[bytes] = None,
@@ -1110,7 +1107,7 @@ class StorageInterface(Protocol):
 
         Args:
             type: one of the values of swh.model.model.MetadataTargetType
-            id: an URL if type is 'origin', else a core SWHID
+            target: an URL if type is 'origin', else a core SWHID
             authority: a dict containing keys `type` and `url`.
             after: minimum discovery_date for a result to be returned
             page_token: opaque token, used to get the next page of results
@@ -1185,7 +1182,7 @@ class StorageInterface(Protocol):
         ...
 
     @remote_api_endpoint("clear/buffer")
-    def clear_buffers(self, object_types: Optional[List[str]] = None) -> None:
+    def clear_buffers(self, object_types: Sequence[str] = ()) -> None:
         """For backend storages (pg, storage, in-memory), this is a noop operation. For proxy
         storages (especially filter, buffer), this is an operation which cleans internal
         state.
@@ -1193,7 +1190,7 @@ class StorageInterface(Protocol):
         """
 
     @remote_api_endpoint("flush")
-    def flush(self, object_types: Optional[List[str]] = None) -> Dict:
+    def flush(self, object_types: Sequence[str] = ()) -> Dict[str, int]:
         """For backend storages (pg, storage, in-memory), this is expected to be a noop
         operation. For proxy storages (especially buffer), this is expected to trigger
         actual writes to the backend.
