@@ -1064,7 +1064,8 @@ def handle_row(row: Dict[str, Any], storage, deposit_cur, dry_run: bool):
         if type_ == "dsc":
             assert origin is None
             origins = debian_origins_from_row(row, storage)
-            assert origins, row
+            if not origins:
+                print("Missing Debian origin for revision: {hash_to_hex(row['id'])}")
         else:
             origins = [origin]
 
