@@ -3,24 +3,30 @@
 # License: GNU General Public License version 3, or any later version
 # See top-level LICENSE file for more information
 
-import pytest
 import multiprocessing.util
 
 from hypothesis import settings
+import pytest
 
 try:
     import pytest_cov.embed
 except ImportError:
     pytest_cov = None
 
+from typing import Iterable
+
+from swh.model.model import BaseContent, Origin
 from swh.model.tests.generate_testdata import gen_contents, gen_origins
-from swh.storage import get_storage
+from swh.storage.interface import StorageInterface
 
 # define tests profile. Full documentation is at:
 # https://hypothesis.readthedocs.io/en/latest/settings.html#settings-profiles
 settings.register_profile("fast", max_examples=5, deadline=5000)
 settings.register_profile("slow", max_examples=20, deadline=5000)
-
+# Load the fast profile by default to overcome default hypothesis values
+# (max_examples=100, deadline=200) that are unsuitable for our tests.
+# This can still be overloaded via the --hypothesis-profile option.
+settings.load_profile("fast")
 
 if pytest_cov is not None:
     # pytest_cov + multiprocessing can cause a segmentation fault when starting
@@ -46,20 +52,15 @@ def swh_storage_backend_config(swh_storage_backend_config):
 
 
 @pytest.fixture
-def swh_storage(swh_storage_backend_config):
-    return get_storage(cls="validate", storage=swh_storage_backend_config)
-
-
-@pytest.fixture
-def swh_contents(swh_storage):
-    contents = gen_contents(n=20)
-    swh_storage.content_add([c for c in contents if c["status"] != "absent"])
-    swh_storage.skipped_content_add([c for c in contents if c["status"] == "absent"])
+def swh_contents(swh_storage: StorageInterface) -> Iterable[BaseContent]:
+    contents = [BaseContent.from_dict(c) for c in gen_contents(n=20)]
+    swh_storage.content_add([c for c in contents if c.status != "absent"])
+    swh_storage.skipped_content_add([c for c in contents if c.status == "absent"])
     return contents
 
 
 @pytest.fixture
-def swh_origins(swh_storage):
-    origins = gen_origins(n=100)
+def swh_origins(swh_storage: StorageInterface) -> Iterable[Origin]:
+    origins = [Origin.from_dict(o) for o in gen_origins(n=100)]
     swh_storage.origin_add(origins)
     return origins
